<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Fashiona
 */

if ( ! function_exists( 'fashiona_wp3_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function fashiona_wp3_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		esc_html_x( 'Posted on %s', 'post date', 'fashiona' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	$byline = sprintf(
		esc_html_x( 'By %s', 'post author', 'fashiona' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

}
endif;

// Prints Author Name.
if ( ! function_exists( 'fashiona_wp3_entry_author' ) ) :
function fashiona_wp3_entry_author() {
	//if (empty (get_theme_mod('hide_posted_by_post_meta'))) {
		if ( 'post' == get_post_type() ) {
		$byline = sprintf(
			_x( '%s ', 'post author', 'fashiona' ),
			'<span class="author vcard"><span class="url fn"><a href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '"> ' . esc_html( get_the_author() ) . '</a></span></span>'
		);
				echo '<span class="theauthor">'. esc_html('Posted By: ','fashiona') . $byline . '</span> | ';
	   }
	//}
}
endif;

// Prints Category.
if ( ! function_exists( 'fashiona_wp3_entry_category' ) ) :
function fashiona_wp3_entry_category() {
	global $post;
    $terms = get_the_terms( $post->ID , 'category' ); 
	if ( $terms != null ){
		echo '<div class="thecategory">';
	        foreach ( $terms as $term ) {
	        $term_link = get_term_link( $term );
	            if( is_wp_error( $term_link ) )
	            continue;
	        echo ' <a href="' . esc_url( $term_link ) . '">' . esc_html( $term->name ) . '</a><span> || </span> ';
			} 
		echo '</div>';
	}
}
endif;


// Prints number of Comments.
if ( ! function_exists( 'fashiona_wp3_entry_comments' ) ) :
function fashiona_wp3_entry_comments() {
	//if (empty (get_theme_mod('hide_comments_counts_post_meta'))) {
		if ( 'post' == get_post_type() ) {
              $num_comments = get_comments_number(); 
			  // get_comments_number returns only a numeric value
                  if ( comments_open() ) {
                       if ( $num_comments == 0 ) {
		       $comments = __('No Comments', 'fashiona' );
	               } elseif ( $num_comments > 1 ) {
		       $comments = $num_comments . __(' Comments', 'fashiona' );
	               } else {
           	       $comments = __('1 Comment', 'fashiona' );
	               }
	               $write_comments = $comments;
                       } else {
	               $write_comments =  __('Comments Off!', 'fashiona' );
                  }
    
		if ( $write_comments ) {
			printf( '<span class="comments"><i class="fa fa-comments"></i> ' . __( '%1$s ', 'fashiona' ) . '</span>', $write_comments );
			}
		}
	//}
}
endif;



if ( ! function_exists( 'fashiona_wp3_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function fashiona_wp3_entry_footer() {

	if ( 'post' === get_post_type() ) {
		if ( get_theme_mod('fashiona_wp3_hide_single_tags',true ) == true ){
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'fashiona' ) );
		if ( $tags_list ) {
			echo '<div class="tag-list">';
			echo 'Tags: <br>';
				printf( '<span class="tags-links">' . esc_html__( '%1$s ', 'fashiona' ) . '</span>  ', $tags_list ); // WPCS: XSS OK.
			echo '</div>';
		}
	}

	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		/* translators: %s: post title */
		comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'fashiona' ), array( 'span' => array( 'class' => array() ) ) ), get_the_title() ) );
		echo '</span>';
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'fashiona' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function fashiona_wp3_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'fashiona_wp3_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'fashiona_wp3_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so fashiona_wp3_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so fashiona_wp3_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in fashiona_wp3_categorized_blog.
 */
function fashiona_wp3_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'fashiona_wp3_categories' );
}
add_action( 'edit_category', 'fashiona_wp3_category_transient_flusher' );
add_action( 'save_post',     'fashiona_wp3_category_transient_flusher' );
